@@ -10,19 +10,18 @@
 #' 
 
 rmse <- function(m, d, verbose=T) {
-  m$RMSE[m$iter] <- sqrt(mean((m$resp - d$resp)^2, na.rm=T))/sd(d$resp, na.rm=T)
+  m$RMSE[m$iter] <- nrmse(d$resp, m$resp)
   
   if(length(m$core.mean)) { # Tucker model
     H.resp <- mult_3d(m$core.mean, m$mode1.H.mean, m$mode2.H.mean, m$mode3.H.mean)
-    m$H.RMSE[m$iter] <- sqrt(mean((H.resp - d$resp)^2, na.rm=T))/sd(d$resp, na.rm=T)
+    m$H.RMSE[m$iter] <- nrmse(d$resp, H.resp)
   } else {  # CP model
     R <- ncol(m$mode1.H.mean)
     core <- array(0, dim=c(R,R,R))
     for(r in 1:R) core[r,r,r] <- 1
     H.resp <- mult_3d(core, m$mode1.H.mean, m$mode2.H.mean, m$mode3.H.mean)
-    m$H.RMSE[m$iter] <- sqrt(mean((H.resp - d$resp)^2, na.rm=T))/sd(d$resp, na.rm=T)
+    m$H.RMSE[m$iter] <- nrmse(d$resp, H.resp)
   }
-  
   if(verbose) {
     print(sprintf("A RMSE: %.4f, H RMSE: %.4f", m$RMSE[m$iter], m$H.RMSE[m$iter]))
   }
